==> commerce_product_availability-1.0.1.tar.gz: commerce_product_availability/src/Plugin/Field/FieldFormatter/ProductAvailabilityDefaultFormatter.php <==
<?php

declare(strict_types=1);

namespace Drupal\commerce_product_availability\Plugin\Field\FieldFormatter;

use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\datetime\Plugin\Field\FieldFormatter\DateTimeDefaultFormatter;

/**
 * Plugin implementation of the 'Product Availability' default formatter.
 *
 * Note, that we are extending the DateTimeDefaultFormatter class, because date
 * time formatting is quite complex and this saves us a lot of work.
 *
 * @FieldFormatter(
 *   id = "commerce_product_availability_product_availability_default",
 *   label = @Translation("Product Availability Default"),
 *   field_types = {"commerce_product_availability_product_availability"},
 * )
 */
class ProductAvailabilityDefaultFormatter extends DateTimeDefaultFormatter {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings(): array {
    return [
      'show_availability_status' => TRUE,
      'show_availability_date' => TRUE,
      'hide_availability_date_in_past' => TRUE,
      'show_min_delivery_period' => TRUE,
      'show_max_delivery_period' => TRUE,
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state): array {
    $form = parent::settingsForm($form, $form_state);

    $form['show_availability_status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show availability status'),
      '#description' => $this->t('Show the availability status of the product.'),
      '#default_value' => $this->getSetting('show_availability_status'),
    ];
    $form['show_availability_date'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show availability date'),
      '#description' => $this->t('Show the date when the product is available.'),
      '#default_value' => $this->getSetting('show_availability_date'),
    ];
    $form['hide_availability_date_in_past'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide availability date if in past'),
      '#description' => $this->t('Hides the availability date if the date is in the past.'),
      '#default_value' => $this->getSetting('hide_availability_date_in_past'),
    ];
    $form['show_min_delivery_period'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show minimum delivery period'),
      '#description' => $this->t('Show the minimum delivery period of the product.'),
      '#default_value' => $this->getSetting('show_min_delivery_period'),
    ];
    $form['show_max_delivery_period'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show maximum delivery period'),
      '#description' => $this->t('Show the maximum delivery period of the product.'),
      '#default_value' => $this->getSetting('show_max_delivery_period'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary(): array {
    return parent::settingsSummary() + [
      $this->t('Show availability status: @show_availability_status', ['@show_availability_status' => (bool) $this->getSetting('show_availability_status') ? 'Yes' : 'No']),
      $this->t('Show availability date: @show_availability_date', ['@show_availability_date' => (bool) $this->getSetting('show_availability_date') ? 'Yes' : 'No']),
      $this->t('Hide availability date if in past: @hide_availability_date_in_past', ['@hide_availability_date_in_past' => (bool) $this->getSetting('hide_availability_date_in_past') ? 'Yes' : 'No']),
      $this->t('Show minimum delivery period: @show_min_delivery_period', ['@show_min_delivery_period' => (bool) $this->getSetting('show_min_delivery_period') ? 'Yes' : 'No']),
      $this->t('Show maximum delivery period: @show_max_delivery_period', ['@show_max_delivery_period' => (bool) $this->getSetting('show_max_delivery_period') ? 'Yes' : 'No']),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];
    foreach ($items as $delta => $item) {
      $elements[$delta] = $this->buildAvailabilityOutput(
          $langcode,
          (bool) $item->orderable,
          $item->availability_status,
          $item->availability_date_object,
          (int) $item->min_delivery_period,
          (int) $item->max_delivery_period,
        );
    }
    return $elements;
  }

  /**
   * Builds the rendered availability output.
   *
   * @param string $langcode
   *   The language code.
   * @param bool $orderable
   *   Whether the product is orderable.
   * @param string|null $availabilityStatus
   *   The availability status of the product.
   * @param \Drupal\Core\Datetime\DrupalDateTime|null $date
   *   The date of availability.
   * @param int|null $minDeliveryPeriod
   *   The minimum delivery period in days.
   * @param int|null $maxDeliveryPeriod
   *   The maximum delivery period in days.
   *
   * @return array
   *   The rendered availability output.
   */
  protected function buildAvailabilityOutput($langcode, bool $orderable, ?string $availabilityStatus, ?DrupalDateTime $date, ?int $minDeliveryPeriod, ?int $maxDeliveryPeriod): array {
    // Hide the date if it is in the past and the setting is enabled OR
    // if the setting to show the date is disabled:
    // Note, I know, that it would be more performant if we negate this
    // statement and run "buildDateWithIsoAttribute" instead. But negating
    // this if statement, makes it unreadable:
    if ($date === NULL || ($this->getSetting('hide_availability_date_in_past') && $date->getTimestamp() < time()) || !$this->getSetting('show_availability_date')) {
      $renderedAvailabilityDate = NULL;
    }
    else {
      $renderedAvailabilityDate = $this->buildDateWithIsoAttribute($date);
    }
    // Hide the min delivery period if the setting is disabled:
    if (!$this->getSetting('show_min_delivery_period')) {
      $minDeliveryPeriod = NULL;
    }
    // Hide the max delivery period if the setting is disabled:
    if (!$this->getSetting('show_max_delivery_period')) {
      $maxDeliveryPeriod = NULL;
    }

    $build = [
      '#theme' => 'commerce_product_availability_product_availability_default',
      '#langcode' => $langcode,
      '#orderable' => $orderable,
      '#availability_status' => $availabilityStatus,
      '#availability_status_label' => commerce_product_availability_get_availability_status_options()[$availabilityStatus],
      '#availability_date' => $renderedAvailabilityDate,
      '#min_delivery_period' => $minDeliveryPeriod,
      '#max_delivery_period' => $maxDeliveryPeriod,
    ];

    return $build;
  }

}

==> commerce_product_availability-1.0.10.tar.gz: commerce_product_availability/src/Plugin/Field/FieldFormatter/ProductAvailabilityDefaultFormatter.php <==
<?php

declare(strict_types=1);

namespace Drupal\commerce_product_availability\Plugin\Field\FieldFormatter;

use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\datetime\Plugin\Field\FieldFormatter\DateTimeDefaultFormatter;

/**
 * Plugin implementation of the 'Product Availability' default formatter.
 *
 * Note, that we are extending the DateTimeDefaultFormatter class, because date
 * time formatting is quite complex and this saves us a lot of work.
 *
 * @FieldFormatter(
 *   id = "commerce_product_availability_product_availability_default",
 *   label = @Translation("Product Availability Default"),
 *   field_types = {"commerce_product_availability_product_availability"},
 * )
 */
class ProductAvailabilityDefaultFormatter extends DateTimeDefaultFormatter {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings(): array {
    return [
      'show_availability_status' => TRUE,
      'show_availability_date' => TRUE,
      'hide_availability_date_in_past' => TRUE,
      'show_min_delivery_period' => TRUE,
      'show_max_delivery_period' => TRUE,
      'show_availability_indicator' => TRUE,
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state): array {
    $form = parent::settingsForm($form, $form_state);

    $form['show_availability_status'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show availability status'),
      '#description' => $this->t('Show the availability status of the product.'),
      '#default_value' => $this->getSetting('show_availability_status'),
    ];
    $form['show_availability_date'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show availability date'),
      '#description' => $this->t('Show the date when the product is available.'),
      '#default_value' => $this->getSetting('show_availability_date'),
    ];
    $form['hide_availability_date_in_past'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide availability date if in past'),
      '#description' => $this->t('Hides the availability date if the date is in the past.'),
      '#default_value' => $this->getSetting('hide_availability_date_in_past'),
    ];
    $form['show_min_delivery_period'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show minimum delivery period'),
      '#description' => $this->t('Show the minimum delivery period of the product.'),
      '#default_value' => $this->getSetting('show_min_delivery_period'),
    ];
    $form['show_max_delivery_period'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show maximum delivery period'),
      '#description' => $this->t('Show the maximum delivery period of the product.'),
      '#default_value' => $this->getSetting('show_max_delivery_period'),
    ];
    $form['show_availability_indicator'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show availability indicator symbol'),
      '#description' => $this->t('Shows a colored availability indicator symbol, which is colored based on the availability of the product:<br>
        <ul>
          <li><strong>Green</strong>: The product is in stock & orderable.</li>
          <li><strong>Yellow</strong>: The product is on preorder / backorder / out of stock & orderable.</li>
          <li><strong>Red</strong>: The product is unorderable</li>
        </ul>. By default a UTF-8 icon truck symbol is used, this can be changed in the twig template.'),
      '#default_value' => $this->getSetting('show_availability_indicator'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary(): array {
    return parent::settingsSummary() + [
      $this->t('Show availability status: @show_availability_status', ['@show_availability_status' => (bool) $this->getSetting('show_availability_status') ? $this->t('Yes') : $this->t('No')]),
      $this->t('Show availability date: @show_availability_date', ['@show_availability_date' => (bool) $this->getSetting('show_availability_date') ? $this->t('Yes') : $this->t('No')]),
      $this->t('Hide availability date if in past: @hide_availability_date_in_past', ['@hide_availability_date_in_past' => (bool) $this->getSetting('hide_availability_date_in_past') ? $this->t('Yes') : $this->t('No')]),
      $this->t('Show minimum delivery period: @show_min_delivery_period', ['@show_min_delivery_period' => (bool) $this->getSetting('show_min_delivery_period') ? $this->t('Yes') : $this->t('No')]),
      $this->t('Show maximum delivery period: @show_max_delivery_period', ['@show_max_delivery_period' => (bool) $this->getSetting('show_max_delivery_period') ? $this->t('Yes') : $this->t('No')]),
      $this->t('Show availability indicator symbol: @show_availability_indicator', ['@show_availability_indicator' => (bool) $this->getSetting('show_availability_indicator') ? $this->t('Yes') : $this->t('No')]),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];
    foreach ($items as $delta => $item) {
      $elements[$delta] = $this->buildAvailabilityOutput(
          $langcode,
          (bool) $item->orderable,
          $item->availability_status,
          $item->availability_date_object,
          (int) $item->min_delivery_period,
          (int) $item->max_delivery_period,
        );
    }
    return $elements;
  }

  /**
   * Builds the rendered availability output.
   *
   * @param string $langcode
   *   The language code.
   * @param bool $orderable
   *   Whether the product is orderable.
   * @param string|null $availabilityStatus
   *   The availability status of the product.
   * @param \Drupal\Core\Datetime\DrupalDateTime|null $date
   *   The date of availability.
   * @param int|null $minDeliveryPeriod
   *   The minimum delivery period in days.
   * @param int|null $maxDeliveryPeriod
   *   The maximum delivery period in days.
   *
   * @return array
   *   The rendered availability output.
   */
  protected function buildAvailabilityOutput($langcode, bool $orderable, ?string $availabilityStatus, ?DrupalDateTime $date, ?int $minDeliveryPeriod, ?int $maxDeliveryPeriod): array {
    // Hide the min availability status if the setting is disabled:
    $availabilityStatusLabel = NULL;
    if ($this->getSetting('show_availability_status')) {
      $availabilityStatusLabel = commerce_product_availability_get_availability_status_options()[$availabilityStatus];
    }
    // Hide the date if it is in the past and the setting is enabled OR
    // if the setting to show the date is disabled:
    // Note, I know, that it would be more performant if we negate this
    // statement and run "buildDateWithIsoAttribute" instead. But negating
    // this if statement, makes it unreadable:
    if ($date === NULL || ($this->getSetting('hide_availability_date_in_past') && $date->getTimestamp() < time()) || !$this->getSetting('show_availability_date')) {
      $renderedAvailabilityDate = NULL;
    }
    else {
      $renderedAvailabilityDate = $this->buildDateWithIsoAttribute($date);
    }
    // Hide the min delivery period if the setting is disabled:
    if (!$this->getSetting('show_min_delivery_period')) {
      $minDeliveryPeriod = NULL;
    }
    // Hide the max delivery period if the setting is disabled:
    if (!$this->getSetting('show_max_delivery_period')) {
      $maxDeliveryPeriod = NULL;
    }

    // Set the Availability truck color:
    $availabilityIndicator = NULL;
    if ($this->getSetting('show_availability_indicator')) {
      if ($orderable) {
        if (in_array($availabilityStatus, ['out_of_stock', 'preorder', 'backorder'])) {
          $availabilityIndicator = 'yellow';
        }
        else {
          $availabilityIndicator = 'green';
        }
      }
      else {
        $availabilityIndicator = 'red';
      }
    }

    $build = [
      '#theme' => 'commerce_product_availability_product_availability_default',
      '#langcode' => $langcode,
      '#orderable' => $orderable,
      '#availability_status' => $availabilityStatus,
      '#availability_status_label' => $availabilityStatusLabel,
      '#availability_date' => $renderedAvailabilityDate,
      '#min_delivery_period' => $minDeliveryPeriod,
      '#max_delivery_period' => $maxDeliveryPeriod,
      '#availability_indicator' => $availabilityIndicator,
      '#attached' => [
        'library' => [
          'commerce_product_availability/availability_indicator',
        ],
      ],
    ];

    return $build;
  }

}
